const parallaxElement = function () { 
    document.addEventListener('DOMContentLoaded', () => {
        const elements = document.querySelectorAll('.parallax-element');

        elements.forEach(element => {
            const speed = parseFloat(element.getAttribute('data-speed')) || 50;
            const scale = parseFloat(element.getAttribute('data-scale')) || 1.1;
            const container = element.closest('.parallax-container');

            const updateTransform = (deltaX, deltaY) => {
                element.style.transform = `translate(${deltaX}px, ${deltaY}px) scale(${scale})`;
            };

            // Mouse move for desktop
            const handleMouseMove = (e) => {
                const { clientX: mouseX, clientY: mouseY } = e;
                const { left, top, width, height } = container.getBoundingClientRect();

                const centerX = (left + width) / 2;
                const centerY = (top + height) / 2;
                const deltaX = (mouseX - centerX) / speed;
                const deltaY = (mouseY - centerY) / speed;

                updateTransform(deltaX, deltaY);
            };

            // Device orientation for mobile
            const handleOrientation = (event) => {
                const alpha = event.alpha || 0; // Rotation around Z-axis
                const beta = event.beta || 0;   // Rotation around X-axis
                const gamma = event.gamma || 0; // Rotation around Y-axis

                // Calculate deltas based on orientation
                const deltaX = (gamma / speed) * 10; // Multiply for sensitivity
                const deltaY = (beta / speed) * 10;

                updateTransform(deltaX, deltaY);
            };

            // Check if the device is mobile
            const isMobile = /Mobi|Android/i.test(navigator.userAgent);

            if (isMobile) {
                window.addEventListener('deviceorientation', handleOrientation);
            } else {
                container.addEventListener('mousemove', handleMouseMove);
            }

            // Reset transform on mouse leave for desktop
            container.addEventListener('mouseleave', () => {
                element.style.transform = 'translate(0, 0) scale(1)';
            });
        });
    });
};

parallaxElement();
